@@ -6,6 +6,9 @@ from marshmallow_annotations.ext.attrs import AttrsSchema
 
 @attr.s(auto_attribs=True, kw_only=True)
 class PopularTable:
+    """
+    DEPRECATED. Use TableSummary
+    """
     database: str = attr.ib()
     cluster: str = attr.ib()
     schema: str = attr.ib()
@@ -14,6 +17,9 @@ class PopularTable:
 
 
 class PopularTableSchema(AttrsSchema):
+    """
+    DEPRECATED. Use TableSummary
+    """
     class Meta:
         target = PopularTable
         register_as_scheme = True
